#ifndef VIFM_TESTS__COLMGR__TEST_H__
#define VIFM_TESTS__COLMGR__TEST_H__

#define RESERVED_COLOR_PAIRS 1
#define CUSTOM_COLOR_PAIRS 127
#define TOTAL_COLOR_PAIRS (RESERVED_COLOR_PAIRS + CUSTOM_COLOR_PAIRS)

#define UNUSED_SEED 99
#define INUSE_SEED 999

#endif /* VIFM_TESTS__COLMGR__TEST_H__ */

/* vim: set tabstop=2 softtabstop=2 shiftwidth=2 noexpandtab cinoptions-=(0 : */
/* vim: set cinoptions+=t0 : */
